const User = require("../models/User");
const jwt = require('jsonwebtoken');
const CryptoJS = require("crypto-js");

const { Op } = require("sequelize");
const { generateTokens } = require("../middleware/token");

const bcrypt = require("bcryptjs");
const { filter } = require("compression");
const UserSub = require("../models/UserSub");
const Sub = require("../models/Sub");

//!  =-=-=-=-=-=-=-=-=-=  Create Admin  =-=-=-=-=-=-=-=-=-=-=//


exports.createAdmin = async () => {
    try {
        const username = await User.findOne({
            where: { username: process.env.ADMIN_USERNAME },
        });
        if (username) {
            return;
        }

        //Hash passwords
        const saltRounds = await bcrypt.genSalt(10);
        const hashedPassword = await bcrypt.hash(
            process.env.ADMIN_PASS,
            saltRounds
        );

        await User.create({
            username: process.env.ADMIN_USERNAME,
            password: hashedPassword,
            role: process.env.ADMIN_ROLE,

        });

        return "Admin created";
    } catch (err) {
        console.log(err);
    }
};

//!  =-=-=-=-=-=-=-=-=-=  Login  =-=-=-=-=-=-=-=-=-=-=//

exports.userLogin = async (req, res) => {
    try {
        const user = await User.findOne({
            where: { username: req.body.username },
            include: [{ model: UserSub, include: [{ model: Sub }] }]
        });
        if (!user) {
            return res.status(401).json({
                success: false,
                message: "Invalid username or PassWord!",
            });
        }

        /**
         * ? this login method with jwt one way hashing
         * @param req.body.password compare with @param user.password from db
         */

        let passwordIsValid = bcrypt.compareSync(req.body.password, user.password);

        if (!passwordIsValid) {
            return res.status(401).json({
                success: false,
                message: "Invalid username or PassWord!",
            });
        }

        //! create Jwt token
        user.hashRt = null
        generateTokens(req, res, user);
        // RefreshToken(req,res,user)

    } catch (err) {

        return res.status(500).json({
            success: false, message: err.message
        });
    }
};
//!  =-=-=-=-=-=-=-=-=-=  Logout  =-=-=-=-=-=-=-=-=-=-=//

exports.logout = (req, res) => {

    req.session.destroy(async (err) => {
        if (err) {

            throw err;
        }



        return res.status(200).json({
            success: true,
            message: "logout",
        });
    });
};

//!  =-=-=-=-=-=-=-=-=-=  Refresh Token  =-=-=-=-=-=-=-=-=-=-=//

exports.RefreshToken = (req, res) => {

    try {
        const { refreshToken } = req.body;

        // Verify the refresh token
        const decryptedRefreshToken = CryptoJS.AES.decrypt(refreshToken, process.env.S_KEY).toString(CryptoJS.enc.Utf8);
        const decoded = jwt.verify(decryptedRefreshToken, process.env.REFRESH_TOKEN_KEY);

        // Check if the refresh token has expired
        if (decoded.exp < Math.floor(Date.now() / 1000)) {
            return res.status(401).json({
                success: false,
                message: 'Refresh token has expired',
            });
        }

        // Assuming decoded.user contains user information
        const user = decoded.user;
        // user.hashRt=null 
        // Generate a new access token


        generateTokens(req, res, user);

    } catch (error) {
        // Handle token verification failure or other errors
        res.status(401).json({
            success: false,
            message: 'Invalid refresh token',
        });
    }
}


//!  =-=-=-=-=-=-=-=-=-=  GET ALL User  =-=-=-=-=-=-=-=-=-=-=//

exports.showAll = async (req, res) => {
    try {
        const whereSearch =
            req.query.search == null ? "%%" : `%${req.query.search}%`;

        const options = {
            page: req.query.page ? parseInt(req.query.page) : 1, // Default 1
            paginate: req.query.paginate ? parseInt(req.query.paginate) : 25, // Default 25
            where: req.query.search
                ? {
                    [Op.or]: [{ fullName: { [Op.like]: whereSearch } }],
                }
                : {},
        };
        const info = await User.paginate(options);

        if (info == null) {
            return res.status(204).json({
                success: false,
                message: "There is no users!",
            });
        } else {
            return res.status(200).json({
                success: true,
                message: "All users info",
                details: info,
            });
        }


    } catch (err) {
        return res.status(500).json({
            success: false,
            message: err.message,
        });
    }
};

//!  =-=-=-=-=-=-=-=-=-=  GEt By ID =-=-=-=-=-=-=-=-=-=-=//

exports.showById = async (req, res) => {
    try {
        const id = req.query.id;
        const info = await User.findOne({
            where: { id: id },
            include: [{ model: UserSub, include: [{ model: Sub }] }]
        });

        if (info == null) {
            return res.status(404).json({
                success: false,
                message: "user not found!",
            });
        } else {
            return res.status(200).json({
                success: true,
                message: "user info",
                info: info,

            });
        }

    } catch (err) {
        return res.status(500).json({
            success: false,
            message: err.message,
        });
    }
};

//!  =-=-=-=-=-=-=-=-=-=  UPDATE  =-=-=-=-=-=-=-=-=-=-=//

exports.updateUser = async (req, res) => {
    try {
        const id = req.query.id;

        const fullName = req.body.fullName == undefined ? undefined : req.body.fullName;
        const mobile = req.body.mobile == undefined ? undefined : req.body.mobile;
        const role = req.body.role == undefined ? undefined : req.body.role;
        const country = req.body.country == undefined ? undefined : req.body.country;
        const status = req.body.status == undefined ? undefined : req.body.status;
        const email = req.body.email == undefined ? undefined : req.body.email;
        const photo = req.files === undefined || req.files.length === 0 ? "" : req.files.map(files => files.filename).join(",")
        const username = req.body.username == undefined ? undefined : req.body.username;

        const saltRounds = await bcrypt.genSalt(10);
        const password = req.body.password === undefined
            ? undefined
            : await bcrypt.hash(req.body.password, saltRounds);

        const result = await User.update(
            {
                fullName,
                mobile,
                role,
                password,
                country,
                status,
                email,
                photo,
                username
            },
            { where: { id: id }, individualHooks: true }
        );

        const user = result[1][0];
        if (result[0] > 0) {


            return res.status(200).json({
                success: true,
                message: `User is updated`,
            });
        } else {

            return res.status(204).json({
                success: false,
                message: `nothing updated for user: ${req.body.username}, may be column not exists`,
            });
        }
    } catch (err) {

        return res.status(500).json({ success: false, message: err.message });
    }
};

//!  =-=-=-=-=-=-=-=-=-=  DELETE  =-=-=-=-=-=-=-=-=-=-=//

exports.deleteUserById = async (req, res) => {
    try {
        const id = req.query.id;
        const user = await User.findByPk(id);

        if (user) {
            await user.destroy();

            return res.status(200).json({
                success: true,
                message: `User with id=${id} was deleted successfully!`,
            });
        } else {
            return res.status(404).json({
                success: false,
                message: "user does not exist!",
            });
        }
    } catch (err) {
        return res.status(500).json({
            success: false,
            message: err.message,
        });
    }
};

//!  =-=-=-=-=-=-=-=-=-=  CREATE  =-=-=-=-=-=-=-=-=-=-=//

exports.addUser = async (req, res) => {
    try {
        const id = req.query.id
        const { username, fullName, mobile, role, country, status, email, password } = req.body;
        const photo = req.files === undefined ? "" : req.files.map(files => files.filename).join(",")
        const userdb = await User.findOne({ where: { email } });

        if (userdb)
            return res.status(409).json({
                success: false,
                message: "user already exists",
            });
        const saltRounds = await bcrypt.genSalt(10);
        const hashedPassword = await bcrypt.hash(password, saltRounds);
        const user = await User.create({
            id,
            fullName,
            mobile,
            role,
            password: hashedPassword,
            country,
            status,
            email,
            photo,
            username
        });

        if (user) {

            return res.status(201).json({
                success: true,
                message: "New user has been added",
                result: user,
            });
        }
    } catch (err) {

        return res.status(500).json({
            success: false,
            message: err.message,
        });
    }
};
