const router = require('express').Router()
const Controller = require("../controller/Answer")
const { authUser,authorizeRoles } = require('../middleware/auth');

router.get('/showall',authUser,Controller.showAll )
router.get('/',authUser,Controller.showById)
router.put('/',authUser,Controller.updateAnswer)
router.delete('/',authUser,Controller.deleteAnswerById)
router.post('/',authUser,Controller.addAnswer)
module.exports = router;

/**
 * @swagger
 * components:
 *   schemas:
 *     Answer:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           description: Unique identifier (UUID) for the Answer
 *         status:
 *           type: boolean
 *           description: Status of the Answer
 *         theoryTrainAttemptsId:
 *           type: string
 *           description: ID of the TheoryTrainAttempts associated with the Answer
 *         choiceId:
 *           type: string
 *           description: ID of the Choice associated with the Answer
 *       required:
 *         - status
 *         - theoryTrainAttemptsId
 *         - choiceId
 *
 * tags:
 *   name: Answer
 *   description: Operations related to Answer management
 */

/**
 * @swagger
 * /answer/showall:
 *   get:
 *     summary: Get all Answers
 *     tags: [Answer]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/Answer'
 */

/**
 * @swagger
 * /answer:
 *   get:
 *     summary: Get a specific Answer by ID
 *     tags: [Answer]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Answer ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Answer'
 */
/**
 * @swagger
 * /answer:
 *   put:
 *     summary: Update a specific Answer
 *     tags: [Answer]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             type: object
 *             properties:
 *               id:
 *                 type: string
 *                 description: ID of the Answer to update
 *               status:
 *                 type: boolean
 *                 description: Status of the Answer
 *             required:
 *               - id
 *               - status
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Answer'
 */

/**
 * @swagger
 * /answer:
 *   delete:
 *     summary: Delete a specific Answer by ID
 *     tags: [Answer]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Answer ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Answer'
 */

/**
 * @swagger
 * /answer:
 *   post:
 *     summary: Add a new Answer
 *     tags: [Answer]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/Answer'
 *           example:
 *             status: true
 *             theoryTrainAttemptsId: "theory_train_attempts_id_here"
 *             choiceId: "choice_id_here"
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Answer'
 */
