const router = require('express').Router()
const Controller = require("../controller/Blog");
const { upload } = require('../middleware/UploadImg');
const { authUser,authorizeRoles } = require('../middleware/auth');

router.get('/showall',authUser,Controller.showAll )
router.get('/',authUser,Controller.showById)
router.put('/',authUser,upload("blogs"),Controller.updateBlog)
router.delete('/',authUser,Controller.deleteBlogById)
router.post('/',authUser,authorizeRoles("admin"),upload("blogs"),Controller.addBlog)


module.exports = router;
/**
 * @swagger
 * components:
 *   schemas:
 *     Blog:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           description: Unique identifier (UUID) for the Blog
 *         title:
 *           type: string
 *           description: Title of the Blog
 *         content:
 *           type: string
 *           description: Content of the Blog
 *         image:
 *           type: string
 *           format: binary
 *           description: Image associated with the Blog
 *         status:
 *           type: boolean
 *           description: Status of the Blog
 *         userId:
 *           type: string
 *           description: Author of the Blog
 *         notes:
 *           type: string
 *           description: Additional notes for the Blog
 *         
 *       required:
 *         - title
 *         - content
 *         - status
 *         - files
 *
 * tags:
 *   name: Blog
 *   description: Operations related to Blog management
 */


/**
 * @swagger
 * /blog/showall:
 *   get:
 *     summary: Get all Blogs or search for Blogs by title
 *     tags: [Blog]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: search
 *         schema:
 *           type: string
 *         description: Search term to filter blogs by title
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/Blog'
 */

/**
 * @swagger
 * /blog:
 *   get:
 *     summary: Get a specific Blog by ID
 *     tags: [Blog]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Blog ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Blog'
 */

/**
 * @swagger
 * /blog:
 *   put:
 *     summary: Update a specific Blog
 *     tags: [Blog]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: ID of the Blog to update
 *     requestBody:
 *       required: true
 *       content:
 *         multipart/form-data:
 *           schema:
 *             type: object
 *             properties:
 *               title:
 *                 type: string
 *               content:
 *                 type: string
 *               status:
 *                 type: boolean
 *               userId:
 *                 type: string
 *               notes:
 *                 type: string
 *               files:
 *                 type: array
 *                 items:
 *                   type: string
 *                   format: binary
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Blog'
 */

/**
 * @swagger
 * /blog:
 *   delete:
 *     summary: Delete a specific Blog by ID
 *     tags: [Blog]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Blog ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Blog'
 */
/**
 * @swagger
 * /blog:
 *   post:
 *     summary: Add a new Blog with an image
 *     tags: [Blog]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Optional ID for the Blog
 *         example: "1"
 *     requestBody:
 *       required: true
 *       content:
 *         multipart/form-data:
 *           schema:
 *             type: object
 *             properties:
 *               title:
 *                 type: string
 *               content:
 *                 type: string
 *               status:
 *                 type: boolean
 *               userId:
 *                 type: string
 *               notes:
 *                 type: string
 *               files:
 *                 type: array
 *                 items:
 *                   type: string
 *                   format: binary
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Blog'
 */
