const router = require('express').Router()
const Controller = require("../controller/Choice");
const { authUser,authorizeRoles } = require('../middleware/auth');

router.get('/showall',authUser,Controller.showAll )
router.get('/',authUser,Controller.showById)
router.put('/',authUser,Controller.updateChoice)
router.delete('/',authUser,Controller.deleteChoiceById)
router.post('/',authUser,Controller.addChoice)


module.exports = router;
/**
 * @swagger
 * components:
 *   schemas:
 *     Choice:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           description: Unique identifier (UUID) for the Choice
 *         choice:
 *           type: string
 *           description: Text of the choice
 *         status:
 *           type: boolean
 *           description: Status of the Choice
 *         questionId:
 *           type: string
 *           description: ID of the associated Question
 *       required:
 *         - choice
 *         - status
 *         - questionId
 *
 * tags:
 *   name: Choice
 *   description: Operations related to Choice management
 */

/**
 * @swagger
 * /choice/showall:
 *   get:
 *     summary: Get all Choices
 *     tags: [Choice]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: search
 *         schema:
 *           type: string
 *         description: Search text to filter choice by choice
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/Choice'
 */

/**
 * @swagger
 * /choice:
 *   get:
 *     summary: Get a specific Choice by ID
 *     tags: [Choice]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Choice ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Choice'
 */

/**
 * @swagger
 * /choice:
 *   put:
 *     summary: Update a specific Choice
 *     tags: [Choice]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             type: object
 *             properties:
 *               id:
 *                 type: string
 *                 description: ID of the Choice to update
 *               choice:
 *                 type: string
 *                 description: Text of the choice
 *               status:
 *                 type: boolean
 *                 description: Status of the Choice
 *             required:
 *               - id
 *               - choice
 *               - status
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Choice'
 */

/**
 * @swagger
 * /choice:
 *   delete:
 *     summary: Delete a specific Choice by ID
 *     tags: [Choice]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Choice ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Choice'
 */

/**
 * @swagger
 * /choice:
 *   post:
 *     summary: Add a new Choice
 *     tags: [Choice]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/Choice'
 *           example:
 *             choice: "Option A"
 *             status: true
 *             questionId: "question_id_here"
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Choice'
 */
