const router = require('express').Router();
const Controller = require("../controller/Exam");
const { authUser, authorizeRoles } = require('../middleware/auth');

// Routes
router.get('/', authUser, Controller.attempt);
router.put('/', authUser, Controller.submit);

module.exports = router;

/**
 * @swagger
 * tags:
 *   name: Exam
 *   description: Operations related to exams
 * 
 * parameters:
 *   userIdQueryParam:
 *     in: query
 *     name: userId
 *     required: true
 *     schema:
 *       type: string
 *     description: ID of the user attempting the exam
 *   theoryTrainIdQueryParam:
 *     in: query
 *     name: theoryTrainId
 *     required: true
 *     schema:
 *       type: string
 *     description: ID of the theory train associated with the exam
 *   theoryTrainAttemptIdQueryParam:
 *     in: query
 *     name: theoryTrainAttemptId
 *     required: true
 *     schema:
 *       type: string
 *     description: ID of the user's theory train attempt
 * 
 * /exam:
 *   get:
 *     summary: Attempt an exam
 *     tags: [Exam]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - $ref: '#/parameters/userIdQueryParam'
 *       - $ref: '#/parameters/theoryTrainIdQueryParam'
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: string
 *               example: "Exam attempted successfully."
 *       '401':
 *         description: Unauthorized request
 *         content:
 *           application/json:
 *             schema:
 *               type: object
 *               properties:
 *                 message:
 *                   type: string
 *                   example: "Unauthorized"
 *       '500':
 *         description: Internal server error
 *         content:
 *           application/json:
 *             schema:
 *               type: object
 *               properties:
 *                 message:
 *                   type: string
 *                   example: "Internal Server Error"
 *   put:
 *     summary: Submit an exam
 *     tags: [Exam]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - $ref: '#/parameters/theoryTrainAttemptIdQueryParam'  # Using theoryTrainAttemptIdQueryParam parameter
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: object
 *               properties:
 *                 success:
 *                   type: boolean
 *                   example: true
 *                 message:
 *                   type: string
 *                   example: "Exam score calculated and saved successfully"
 *                 totalScore:
 *                   type: number
 *                   example: 80  # Example total score
 *       '401':
 *         $ref: '#/components/responses/UnauthorizedError'
 *       '500':
 *         $ref: '#/components/responses/InternalServerError'
 */
