const router = require('express').Router()
const Controller = require("../controller/Faq")
const { authUser,authorizeRoles } = require('../middleware/auth');

router.get('/showall',Controller.showAll )
router.get('/',authUser,Controller.showById)
router.put('/',authUser,Controller.updateFaq)
router.delete('/',authUser,Controller.deleteFaqById)
router.post('/',authUser,Controller.addFaq)


module.exports = router;



/**
 * @swagger
 * components:
 *   schemas:
 *     Faq:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           description: Unique identifier (UUID) for the FAQ
 *         title:
 *           type: string
 *           description: Title of the FAQ
 *         description:
 *           type: string
 *           description: Description of the FAQ
 *         status:
 *           type: boolean
 *           description: Status of the FAQ
 *         
 */             

/**
 * @swagger
 * tags:
 *   name: FAQ
 *   description: Operations related to FAQ management
 */
/**
 * @swagger
 * /faq/showall:
 *   get:
 *     summary: Get all FAQs
 *     tags: [FAQ]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: search
 *         schema:
 *           type: string
 *         description: Search text to filter FAQs by title
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/Faq'
 */


/**
 * @swagger
 * /faq:
 *   get:
 *     summary: Get a specific FAQ by ID
 *     tags: [FAQ]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: FAQ ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Faq'
 */

/**
 /**
 * @swagger
 * /faq:
 *   put:
 *     summary: Update a specific FAQ
 *     tags: [FAQ]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *         schema:
 *           type: string
 *         required: true
 *         description: ID of the FAQ to update
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/Faq'
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Faq'
 */

/**
 * @swagger
 * /faq:
 *   delete:
 *     summary: Delete a specific FAQ by ID
 *     tags: [FAQ]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: FAQ ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Faq'
 */

/**
 * @swagger
 * /faq:
 *   post:
 *     summary: Add a new FAQ
 *     tags: [FAQ]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/Faq'
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Faq'
 */
