const router = require('express').Router()
const Controller = require("../controller/PracTrainPlayList")
const { authUser,authorizeRoles } = require('../middleware/auth');

router.get('/showall',authUser,Controller.showAll )
router.get('/',authUser,Controller.showById)
router.put('/',authUser,Controller.updatePracList)
router.delete('/',authUser,Controller.deletePracListById)
router.post('/',authUser,Controller.addPracList)

module.exports = router;
/**
 * @swagger
 * components:
 *   schemas:
 *     PracList:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           format: uuid
 *           description: Unique identifier (UUID) for the practice list
 *         title:
 *           type: string
 *           description: Title of the practice list
 *         playListUrl:
 *           type: string
 *           description: URL for the practice list
 *         description:
 *           type: string
 *           description: Description of the practice list
 *         status:
 *           type: boolean
 *           description: Status of the practice list
 *       required:
 *         - title
 *         - playListUrl
 *
 * tags:
 *   name: PracList
 *   description: Operations related to practice list management
 */

/**
 * @swagger
 * /pracLists/showall:
 *   get:
 *     summary: Get all practice lists
 *     tags: [PracList]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: search
 *         schema:
 *           type: string
 *         description: Search text to filter practice lists by title
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/PracList'
 */

/**
 * @swagger
 * /pracLists:
 *   get:
 *     summary: Get a specific practice list by ID
 *     tags: [PracList]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Practice list ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/PracList'
 */

/**
 * @swagger
 * /pracLists:
 *   put:
 *     summary: Update a specific practice list
 *     tags: [PracList]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/PracList'
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/PracList'
 */

/**
 * @swagger
 * /pracLists:
 *   delete:
 *     summary: Delete a specific practice list by ID
 *     tags: [PracList]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Practice list ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/PracList'
 */

/**
 * @swagger
 * /pracLists:
 *   post:
 *     summary: Add a new practice list
 *     tags: [PracList]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/PracList'
 *       example:
 *         title: "Practice List 1"
 *         playListUrl: "https://example.com/playlist1"
 *         description: "This is a practice list for training."
 *         status: "active"
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/PracList'
 */
