const router = require('express').Router()
const Controller = require("../controller/PracTrainVideo")
const { authUser,authorizeRoles } = require('../middleware/auth');

router.get('/showall',authUser,Controller.showAll )
router.get('/',authUser,Controller.showById)
router.put('/',authUser,Controller.updatePracvideo)
router.delete('/',authUser,Controller.deletePracVideotById)
router.post('/',authUser,Controller.addPracVideo)

module.exports = router;
/**
 * @swagger
 * components:
 *   schemas:
 *     PracVideo:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           format: uuid
 *           description: Unique identifier (UUID) for the practice video
 *         title:
 *           type: string
 *           description: Title of the practice video
 *         videoUrl:
 *           type: string
 *           description: URL for the practice video
 *         description:
 *           type: string
 *           description: Description of the practice video
 *         status:
 *           type: boolean
 *           description: Status of the practice video
 *         pracListId:
 *           type: string
 *           format: uuid
 *           description: ID of the associated practice list
 *       required:
 *         - title
 *         - videoUrl
 *         - pracListId
 *
 * tags:
 *   name: PracVideo
 *   description: Operations related to practice video management
 */
/**
 * @swagger
 * /pracvideos/showall:
 *   get:
 *     summary: Get all practice videos
 *     tags: [PracVideo]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: search
 *         schema:
 *           type: string
 *         description: Search text to filter practice videos by title
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/PracVideo'
 */

/**
 * @swagger
 * /pracvideos:
 *   get:
 *     summary: Get a specific practice video by ID
 *     tags: [PracVideo]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Practice video ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/PracVideo'
 */

/**
 * @swagger
 * /pracvideos:
 *   put:
 *     summary: Update a specific practice video
 *     tags: [PracVideo]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/PracVideo'
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/PracVideo'
 */

/**
 * @swagger
 * /pracvideos:
 *   delete:
 *     summary: Delete a specific practice video by ID
 *     tags: [PracVideo]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Practice video ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/PracVideo'
 */

/**
 * @swagger
 * /pracvideos:
 *   post:
 *     summary: Add a new practice video
 *     tags: [PracVideo]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/PracVideo'
 *       example:
 *         title: "Practice Video 1"
 *         videoUrl: "https://example.com/video1"
 *         description: "This is a practice video for training."
 *         status: "active"
 *         pracListId: "playlist-id-123"
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/PracVideo'
 */
