const router = require('express').Router()
const Controller = require("../controller/PreviewVideo")
const { authUser,authorizeRoles } = require('../middleware/auth');

router.get('/showall',authUser,Controller.showAll )
router.get('/',authUser,Controller.showById)
router.put('/',authUser,Controller.updatePrevVideo)
router.delete('/',authUser,Controller.deletePrevVideoById)
router.post('/',authUser,Controller.addPrevVideo)

module.exports = router;

/**
 * @swagger
 * components:
 *   schemas:
 *     PreviewVideo:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           format: uuid
 *           description: Unique identifier (UUID) for the preview video
 *         status:
 *           type: boolean
 *           description: Status of the preview video
 *         userId:
 *           type: string
 *           format: uuid
 *           description: ID of the associated user
 *         pracVideoId:
 *           type: string
 *           format: uuid
 *           description: ID of the associated practice video
 *       required:
 *         - status
 *         - userId
 *         - pracVideoId
 *
 * tags:
 *   name: PreviewVideo
 *   description: Operations related to preview video management
 */

/**
 * @swagger
 * /previewvideos/showall:
 *   get:
 *     summary: Get all preview videos
 *     tags: [PreviewVideo]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/PreviewVideo'
 */

/**
 * @swagger
 * /previewvideos:
 *   get:
 *     summary: Get a specific preview video by ID
 *     tags: [PreviewVideo]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Preview video ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/PreviewVideo'
 */

/**
 * @swagger
 * /previewvideos:
 *   put:
 *     summary: Update a specific preview video
 *     tags: [PreviewVideo]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/PreviewVideo'
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/PreviewVideo'
 */

/**
 * @swagger
 * /previewvideos:
 *   delete:
 *     summary: Delete a specific preview video by ID
 *     tags: [PreviewVideo]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Preview video ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/PreviewVideo'
 */

/**
 * @swagger
 * /previewvideos:
 *   post:
 *     summary: Add a new preview video
 *     tags: [PreviewVideo]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/PreviewVideo'
 *       example:
 *         status: "active"
 *         userId: "user-id-123"
 *         pracVideoId: "pracvideo-id-456"
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/PreviewVideo'
 */
