const router = require('express').Router();
const Controller = require("../controller/Question");
const { upload } = require('../middleware/UploadImg');
const { authUser } = require('../middleware/auth');

router.get('/showall', authUser, Controller.showAll);
router.get('/', authUser, Controller.showById);
router.get('/QStatus', authUser, Controller.showQStatus);
router.put('/', authUser, upload("questions"), Controller.updateQuestion);
router.delete('/', authUser, Controller.deleteQuestionById);
router.post('/', authUser, upload("questions"), Controller.addQuestion);

module.exports = router;

/**
 * @swagger
 * components:
 
 *   schemas:
 *     Question:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           description: Unique identifier (UUID) for the Question
 *         question:
 *           type: string
 *           description: The question text
 *         score:
 *           type: string
 *           description: The score associated with the question
 *         img:
 *           type: string
 *           format: binary
 *           description: Image associated with the Question
 *         status:
 *           type: boolean
 *           description: Status of the Question
 *         theoryTrainId:
 *           type: string
 *           description: ID of the associated TheoryTrain
 *
 * tags:
 *   name: Question
 *   description: Operations related to Question management
 */

/**
 * @swagger
 * /questions/showall:
 *   get:
 *     summary: Get all Questions
 *     tags: [Question]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: search
 *         schema:
 *           type: string
 *         description: Search text to filter questions by question
 *       - in: query
 *         name: theorytrainId
 *         schema:
 *           type: string
 *         description: ID of the associated TheoryTrain
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/Question'
 */

/**
 * @swagger
 * /questions:
 *   get:
 *     summary: Get a specific Question by ID
 *     tags: [Question]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Question ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Question'
 */

/**
 * @swagger
 * /questions:
 *   put:
 *     summary: Update a specific Question
 *     tags: [Question]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: ID of the Question to update
 *     requestBody:
 *       required: true
 *       content:
 *         multipart/form-data:
 *           schema:
 *             type: object
 *             properties:
 *               question:
 *                 type: string
 *               score:
 *                 type: string
 *               files:
 *                 type: array
 *                 items:
 *                   type: string
 *                   format: binary
 *               status:
 *                 type: boolean
 *               theoryTrainId:
 *                 type: string
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Question'
 */

/**
 * @swagger
 * /questions:
 *   delete:
 *     summary: Delete a specific Question by ID
 *     tags: [Question]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Question ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Question'
 */
/**
 * @swagger
 * /questions:
 *   post:
 *     summary: Add a new question with choices
 *     tags: [Question]
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Optional ID for the question
 *         example: "1"
 *     requestBody:
 *       required: true
 *       content:
 *         multipart/form-data:
 *           schema:
 *             type: object
 *             properties:
 *               theoryTrainId:
 *                 type: string
 *                 description: ID of the theory train associated with the question
 *               question:
 *                 type: string
 *                 description: Text of the question
 *               score:
 *                 type: integer
 *                 description: Score of the question
 *               status:
 *                 type: boolean
 *                 description: Status of the question
 *               files:
 *                 type: array
 *                 items:
 *                   type: string
 *                   format: binary
 *                 description: List of image files associated with the question
 *               choices:
 *                 type: string
 *                 description: JSON array of choice objects
 *                 example: '[{"choice":"Option A","status":true},{"choice":"Option B","status":false}]'
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: object
 *               properties:
 *                 success:
 *                   type: boolean
 *                   example: true
 *                 message:
 *                   type: string
 *                   example: "New question and choices have been added"
 *                 result:
 *                   $ref: '#/components/schemas/Question'
 *       '400':
 *         description: Bad request
 *         content:
 *           application/json:
 *             schema:
 *               type: object
 *               properties:
 *                 success:
 *                   type: boolean
 *                   example: false
 *                 message:
 *                   type: string
 *                   example: "Invalid request format"
 *       '500':
 *         description: Internal server error
 *         content:
 *           application/json:
 *             schema:
 *               type: object
 *               properties:
 *                 success:
 *                   type: boolean
 *                   example: false
 *                 message:
 *                   type: string
 *                   example: "Internal Server Error"
 */


/**
 * @swagger
 * /questions/QStatus:
 *   get:
 *     summary: Get status of questions for a specific userTheoryTrainId
 *     tags: [Question]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: userTheoryTrainId
 *         schema:
 *           type: string
 *         description: ID of the userTheoryTrain
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: object
 *               properties:
 *                 success:
 *                   type: boolean
 *                 message:
 *                   type: string
 *                 details:
 *                   type: object
 *                   properties:
 *                     withAnswers:
 *                       type: array
 *                       items:
 *                         $ref: '#/components/schemas/Question'
 *                     withoutAnswers:
 *                       type: array
 *                       items:
 *                         $ref: '#/components/schemas/Question'
 *       '204':
 *         description: No questions found for the specified userTheoryTrainId
 *         content:
 *           application/json:
 *             schema:
 *               type: object
 *               properties:
 *                 success:
 *                   type: boolean
 *                 message:
 *                   type: string
 */
