const router = require('express').Router()
const Controller = require("../controller/School")
const { authUser,authorizeRoles } = require('../middleware/auth');

router.get('/showall',authUser,Controller.showAll )
router.get('/',authUser,Controller.showById)
router.put('/',authUser,Controller.updateSchool)
router.delete('/',authUser,Controller.deleteSchoolById)
router.post('/',Controller.addSchool)

module.exports = router;
/**
 * @swagger
 * components:
 *   schemas:
 *     School:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           description: Unique identifier (UUID) for the school
 *         name:
 *           type: string
 *           description: Name of the school
 *         address:
 *           type: string
 *           description: Address of the school
 *         phone:
 *           type: string
 *           description: Phone number of the school
 *         email:
 *           type: string
 *           description: Email address of the school
 *         notes:
 *           type: string
 *           description: Additional notes for the school
 *         status:
 *           type: boolean
 *           description: Status of the school
 *       required:
 *         - name
 *
 * tags:
 *   name: Schools
 *   description: Operations related to school management
 */

/**
 * @swagger
 * /school/showall:
 *   get:
 *     summary: Get all schools
 *     tags: [Schools]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: search
 *         schema:
 *           type: string
 *         description: Search text to filter schools by name
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/School'
 */

/**
 * @swagger
 * /school:
 *   get:
 *     summary: Get a specific school by ID
 *     tags: [Schools]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: School ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/School'
 */

/**
 * @swagger
 * /school:
 *   put:
 *     summary: Update a specific school
 *     tags: [Schools]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/School'
 *       example:
 *         name: "Updated School"
 *         address: "Updated Address"
 *         phone: "123-456-7890"
 *         email: "updated@example.com"
 *         notes: "Updated notes"
 *         status: true
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/School'
 */

/**
 * @swagger
 * /school:
 *   delete:
 *     summary: Delete a specific school by ID
 *     tags: [Schools]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: School ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/School'
 */

/**
 * @swagger
 * /school:
 *   post:
 *     summary: Add a new school
 *     tags: [Schools]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/School'
 *       example:
 *         name: "New School"
 *         address: "New Address"
 *         phone: "987-654-3210"
 *         email: "new@example.com"
 *         notes: "New notes"
 *         status: true
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/School'
 */
