const router = require('express').Router()
const Controller = require("../controller/Sub")
const { authUser,authorizeRoles } = require('../middleware/auth');

router.get('/showall',Controller.showAll )
router.get('/',authUser,Controller.showById)
router.put('/',authUser,Controller.updateSub)
router.delete('/',authUser,Controller.deleteSubById)
router.post('/',authUser,Controller.addSub)
module.exports = router;

/**
 * @swagger
 * components:
 *   schemas:
 *     Sub:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           description: Unique identifier (UUID) for the subscription
 *         type:
 *           type: string
 *           description: Type of the subscription
 *         description:
 *           type: string
 *           description: Description of the subscription
 *         price:
 *           type: number
 *           description: Price of the subscription
 *         attempts:
 *           type: number
 *           description: Whether attempts are allowed for the subscription
 *         status:
 *           type: boolean
 *           description: Status of the subscription
 *       required:
 *         - type
 *         - price
 *
 * tags:
 *   name: Subs
 *   description: Operations related to subscription management
 */

/**
 * @swagger
 * /subs/showall:
 *   get:
 *     summary: Get all subscriptions
 *     tags: [Subs]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: search
 *         schema:
 *           type: string
 *         description: Search text to filter subscriptions by type
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/Sub'
 */

/**
 * @swagger
 * /subs:
 *   get:
 *     summary: Get a specific subscription by ID
 *     tags: [Subs]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Subscription ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Sub'
 */

/**
 * @swagger
 * /subs:
 *   put:
 *     summary: Update a specific subscription
 *     tags: [Subs]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/Sub'
 *       example:
 *         type: "Updated Type"
 *         description: "Updated description"
 *         price: 19.99
 *         attempts: true
 *         status: true
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Sub'
 */

/**
 * @swagger
 * /subs:
 *   delete:
 *     summary: Delete a specific subscription by ID
 *     tags: [Subs]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Subscription ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Sub'
 */

/**
 * @swagger
 * /subs:
 *   post:
 *     summary: Add a new subscription
 *     tags: [Subs]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/Sub'
 *       example:
 *         type: "New Type"
 *         description: "New description"
 *         price: 29.99
 *         attempts: false
 *         status: true
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/Sub'
 */
