const router = require('express').Router()
const Controller = require("../controller/TheoryTrain")
const { authUser,authorizeRoles } = require('../middleware/auth');

router.get('/showall',authUser,Controller.showAll )
router.get('/',authUser,Controller.showById)
router.put('/',authUser,Controller.updateTheoryTrain)
router.delete('/',authUser,Controller.deleteTheoryTrainById)
router.post('/',authUser,Controller.addTheoryTrain)
module.exports = router;


/**
 * @swagger
 * components:
 *   schemas:
 *     TheoryTrain:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           format: uuid
 *           description: Unique identifier (UUID) for the theory training
 *         title:
 *           type: string
 *           description: Title of the theory training
 *         period:
 *           type: boolean
 *           description: Period of the theory training
 *         description:
 *           type: text
 *           description: Description of the theory training
 *         status:
 *           type: boolean
 *           description: Status of the theory training
 *       required:
 *         - title
 *         - period
 *
 * tags:
 *   name: TheoryTrain
 *   description: Operations related to theory training management
 */

/**
 * @swagger
 * /theorytrains/showall:
 *   get:
 *     summary: Get all theory trains
 *     tags: [TheoryTrain]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: search
 *         schema:
 *           type: string
 *         description: Search text to filter theory trains by title
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/TheoryTrain'
 */

/**
 * @swagger
 * /theorytrains:
 *   get:
 *     summary: Get a specific theory train by ID
 *     tags: [TheoryTrain]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Theory train ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/TheoryTrain'
 */

/**
 * @swagger
 * /theorytrains:
 *   put:
 *     summary: Update a specific theory train
 *     tags: [TheoryTrain]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/TheoryTrain'
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/TheoryTrain'
 */

/**
 * @swagger
 * /theorytrains:
 *   delete:
 *     summary: Delete a specific theory train by ID
 *     tags: [TheoryTrain]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Theory train ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/TheoryTrain'
 */

/**
 * @swagger
 * /theorytrains:
 *   post:
 *     summary: Add a new theory train
 *     tags: [TheoryTrain]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/TheoryTrain'
 *       example:
 *         title: "Introduction to Theory"
 *         period: true
 *         description: "A comprehensive introduction to theory training."
 *         status: true
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/TheoryTrain'
 */
