const router = require('express').Router()
const Controller = require("../controller/TheoryTrainAttempts")
const { authUser,authorizeRoles } = require('../middleware/auth');

router.get('/showall',authUser,Controller.showAll )
router.get('/showAllByUserTheoryTrainAndUserId',authUser,Controller.showAllByUserTheoryTrainAndUserId )
router.get('/',authUser,Controller.showById)
router.put('/',authUser,Controller.updateTheoryTrainAttempts)
router.delete('/',authUser,Controller.deleteTheoryTrainAttemptsById)
router.post('/',authUser,Controller.addTheoryTrainAttempts)
module.exports = router;

/**
 * @swagger
 * components:
 *   schemas:
 *     TheoryTrainAttempts:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           format: uuid
 *           description: Unique identifier (UUID) for the theory training attempt
 *         endAt:
 *           type: string
 *           format: date-time
 *           description: End time of the theory training attempt
 *         score:
 *           type: number
 *           description: Score achieved in the theory training attempt
 *         status:
 *           type: boolean
 *           description: Status of the theory training attempt
 *       required:
 *         - endAt
 *         - status
 *
 * tags:
 *   name: TheoryTrainAttempts
 *   description: Operations related to theory training attempts management
 */

/**
 * @swagger
 * /theorytrainattempts/showall:
 *   get:
 *     summary: Get all theory train attempts
 *     tags: [TheoryTrainAttempts]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/TheoryTrainAttempts'
 */

/**
 * @swagger
 * /theorytrainattempts/showAllByUserTheoryTrainAndUserId:
 *   get:
 *     summary: Get all theory train attempts
 *     tags: [TheoryTrainAttempts]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: userId
 *         schema:
 *           type: string
 *         description: userId
 *       - in: query
 *         name: userTheoryTrainId
 *         schema:
 *          type: string
 *         description: userTheoryTrainId  
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/TheoryTrainAttempts'
 */

/**
 * @swagger
 * /theorytrainattempts:
 *   get:
 *     summary: Get a specific theory train attempt by ID
 *     tags: [TheoryTrainAttempts]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Theory train attempt ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/TheoryTrainAttempts'
 */

/**
 * @swagger
 * /theorytrainattempts:
 *   put:
 *     summary: Update a specific theory train attempt
 *     tags: [TheoryTrainAttempts]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/TheoryTrainAttempts'
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/TheoryTrainAttempts'
 */

/**
 * @swagger
 * /theorytrainattempts:
 *   delete:
 *     summary: Delete a specific theory train attempt by ID
 *     tags: [TheoryTrainAttempts]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Theory train attempt ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/TheoryTrainAttempts'
 */

/**
 * @swagger
 * /theorytrainattempts:
 *   post:
 *     summary: Add a new theory train attempt
 *     tags: [TheoryTrainAttempts]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             type: object
 *             properties:
 *               endAt:
 *                 type: string
 *                 format: date-time
 *                 description: End time of the theory training attempt
 *               score:
 *                 type: number
 *                 description: Score achieved in the theory training attempt
 *               status:
 *                 type: boolean
 *                 description: Status of the theory training attempt
 *               userTheoryTrainId:
 *                 type: string
 *                 format: uuid
 *                 description: ID of the associated user theory train
 *             required:
 *               - endAt
 *               - status
 *               - userTheoryTrainId
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/TheoryTrainAttempts'
 *     example:
 *       endAt: "3:15"
 *       score: 90
 *       status: true
 *       userTheoryTrainId: "userTheoryTrainId"
 */
