const router = require('express').Router()
const userController = require("../controller/User")
const { upload } = require('../middleware/UploadImg');
const { authUser, authorizeRoles } = require('../middleware/auth');

router.get('/showall', authUser, userController.showAll)
router.get('/', authUser, userController.showById)
router.put('/', authUser, upload("users"),userController.updateUser)
router.delete('/', authUser, userController.deleteUserById)
router.post('/register', upload("users"),userController.addUser)
router.get('/logout', authUser, userController.logout)
router.post('/login', userController.userLogin)
router.post('/refresh', userController.RefreshToken)


module.exports = router;


/**
 * @swagger
 * components:
 *   schemas:
 *     User:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           description: Unique identifier (UUID) for the Blog
 *         fullName:
 *           type: string
 *           description: Full name of the user
 *         role:
 *           type: string
 *           description: User role
 *         password:
 *           type: string
 *           description: User password
 *         country:
 *           type: string
 *           description: Country of the user
 *         mobile:
 *           type: string
 *           description: Mobile number of the user
 *         email:
 *           type: string
 *           description: Email address of the user
 *         status:
 *           type: boolean
 *           description: User status (active/inactive)
 *         photo:
 *           type: string
 *           format: binary
 *           description: URL or path to the user's photo
 *         username:
 *           type: string
 *           description: username
 *        
 */

/**
 * @swagger
 * tags:
 *   name: User
 *   description: Operations related to user management
 */

/**
 * @swagger
 * /user/showall:
 *   get:
 *     summary: Get all users
 *     tags: [User]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: search
 *         schema:
 *           type: string
 *         description: Search text to filter users by fullName
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/User'
 */

/**
 * @swagger
 * /user:
 *   get:
 *     summary: Get a specific user by ID
 *     tags: [User]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: User ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/User'
 */

/**
 * @swagger
 * /user:
 *   put:
 *     summary: Update a specific user
 *     tags: [User]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: ID of the user to update
 *     requestBody:
 *       required: true
 *       content:
 *         multipart/form-data:
 *           schema:
 *             type: object
 *             properties:
 *               fullName:
 *                 type: string
 *               role:
 *                 type: string
 *               password:
 *                 type: string
 *               country:
 *                 type: string
 *               mobile:
 *                 type: string
 *               email:
 *                 type: string
 *               status:
 *                 type: boolean
 *               files:
 *                 type: array
 *                 items:
 *                   type: string
 *                   format: binary
 *               username:
 *                 type: string
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/User'
 */
/**
 * @swagger
 * /user:
 *   delete:
 *     summary: Delete a specific user by ID
 *     tags: [User]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: User ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/User'
 */

/**
 * @swagger
 * /user/register:
 *   post:
 *     summary: Register a new user
 *     tags: [User]
 *     security: []
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: Optional ID for the Question
 *         example: "1"
 *     requestBody:
 *       required: true
 *       content:
 *         multipart/form-data:
 *           schema:
 *             type: object
 *             properties:
 *               fullName:
 *                 type: string
 *               role:
 *                 type: string
 *               password:
 *                 type: string
 *               country:
 *                 type: string
 *               mobile:
 *                 type: string
 *               email:
 *                 type: string
 *               status:
 *                 type: boolean
 *               files:
 *                 type: array
 *                 items:
 *                   type: string
 *                   format: binary
 *               username:
 *                 type: string
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/User'
 */


/**
 * @swagger
 * /user/login:
 *   post:
 *     summary: Login with user credentials
 *     tags: [User]
 *     security: []
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             type: object
 *             properties:
 *               username:
 *                 type: string
 *               password:
 *                 type: string
 *             required:
 *               - username
 *               - password
 *           example:
 *             username: "John Doe"
 *             password: "some_secure_password"
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: object
 *               properties:
 *                 success:
 *                   type: boolean
 *                   description: Indicates if the login was successful
 *                   example: true
 *                 message:
 *                   type: string
 *                   description: Login message
 *                   example: "Login successful"
 *                 token:
 *                   type: string
 *                   description: JWT access token
 *                   example: "some_jwt_access_token"
 *                 user:
 *                   $ref: '#/components/schemas/User'
 *                 sessionID:
 *                   type: string
 *                   description: Unique session ID
 *                   example: "unique_session_id"
 */

/**
 * @swagger
 * /user/refresh:
 *   post:
 *     summary: Refresh JWT token
 *     tags: [User]
 *     security: []
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             type: object
 *             properties:
 *               refreshToken:
 *                 type: string
 *                 description: Refresh token for authentication
 *                 example: "some_refresh_token"
 *             required:
 *               - refreshToken
 *           example:
 *             refreshToken: "some_refresh_token"
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: object
 *               properties:
 *                 success:
 *                   type: boolean
 *                   description: Indicates if the refresh was successful
 *                   example: true
 *                 message:
 *                   type: string
 *                   description: Refresh message
 *                   example: "Token refreshed successfully"
 *                 token:
 *                   type: string
 *                   description: New JWT access token
 *                   example: "new_jwt_access_token"
 *                 user:
 *                   $ref: '#/components/schemas/User'
 *                 sessionID:
 *                   type: string
 *                   description: Unique session ID
 *                   example: "unique_session_id"
 */
/**
 * @swagger
 * /user/logout:
 *   get:
 *     summary: Logout the current user
 *     tags: [User]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: object
 *               properties:
 *                 message:
 *                   type: string
 *                   description: Logout message
 *                   example: "User logged out successfully"
 */