const router = require('express').Router()
const Controller = require("../controller/UserSub")
const { authUser,authorizeRoles } = require('../middleware/auth');

router.get('/showall',authUser,Controller.showAll )
router.get('/',authUser,Controller.showById)
router.put('/',authUser,Controller.updateUserSubscriptions)
router.delete('/',authUser,Controller.deleteUserSubscriptionsById)
router.post('/',authUser,Controller.addUserSubscriptions)
module.exports = router;

/**
 * @swagger
 * components:
 *   schemas:
 *     UserSub:
 *       type: object
 *       properties:
 *         id:
 *           type: string
 *           description: Unique identifier (UUID) for the user subscription
 *         subDate:
 *           type: string
 *           format: date
 *           description: Subscription start date
 *         subExpiryDate:
 *           type: string
 *           format: date
 *           description: Subscription expiry date
 *         status:
 *           type: boolean
 *           description: Status of the user subscription
 *         userId:
 *           type: string
 *           description: User ID associated with the subscription
 *         subId:
 *           type: string
 *           description: Subscription ID associated with the user
 *       required:
 *         - subDate
 *         - subExpiryDate
 *         - userId
 *         - subId
 *
 * tags:
 *   name: UserSubs
 *   description: Operations related to user subscriptions management
 */

/**
 * @swagger
 * /usersubs/showall:
 *   get:
 *     summary: Get all user subscriptions
 *     tags: [UserSubs]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               type: array
 *               items:
 *                 $ref: '#/components/schemas/UserSub'
 */

/**
 * @swagger
 * /usersubs:
 *   get:
 *     summary: Get a specific user subscription by ID
 *     tags: [UserSubs]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: User Subscription ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/UserSub'
 */

/**
 * @swagger
 * /usersubs:
 *   put:
 *     summary: Update a specific user subscription
 *     tags: [UserSubs]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/UserSub'
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/UserSub'
 */



/**
 * @swagger
 * /usersubs:
 *   delete:
 *     summary: Delete a specific user subscription by ID
 *     tags: [UserSubs]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     parameters:
 *       - in: query
 *         name: id
 *         schema:
 *           type: string
 *         description: User Subscription ID
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/UserSub'
 */

/**
 * @swagger
 * /usersubs:
 *   post:
 *     summary: Add a new user subscription
 *     tags: [UserSubs]
 *     security:
 *       - TokenAuth: []  # Requires a valid JWT token
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             $ref: '#/components/schemas/UserSub'
 *       example:
 *         subDate: "2024-01-25"
 *         subExpiryDate: "2025-01-25"
 *         status: true
 *         userId: "user-id-123"
 *         subId: "subscription-id-456"
 *     responses:
 *       '200':
 *         description: Successful operation
 *         content:
 *           application/json:
 *             schema:
 *               $ref: '#/components/schemas/UserSub'
 */
